import h5py
import numpy as np
from artist_pythonlib import API
from tqdm import tqdm
from h5schemas.projection_geometry.overwrite_projection_geometry import overwrite_projection_geometry_at_index



FOD = 1000.
FDD = 2000.
DISTANCE = 20
DELTA = 0.01

def set_source_detector(api: API, z: float):
    api.translate('S', 0., FOD, z)
    api.translate('D', 0., FOD-FDD, z)
    api.rotate('D', 90, 0, 0)

def add_error(api: API, error_source, error_detector):
    error_source += (np.random.random(3) - 0.5) * 2 * 0.01
    error_detector += (np.random.random(3) - 0.5) * 2 * 0.01

    source = api.get_position('S')
    api.translate('S', *(source + error_source))

    detector = api.get_position('D')
    api.translate('D', *(detector + error_detector))

    return error_source, error_detector

def main():
    file = h5py.File('./temp/fly_by_linear.h5', 'a')
    api = API()
    error_source, error_detector = np.zeros((3,)), np.ones((3,))

    z_steps = np.linspace(-DISTANCE / 2, DISTANCE / 2, int(DISTANCE / DELTA))

    for i in tqdm(range(z_steps.shape[0])):
        z = z_steps[i]
        set_source_detector(api, z)
        error_source, error_detector = add_error(api, error_source, error_detector)
        api.save_hdf5(file)
        overwrite_projection_geometry_at_index(
            file['projection_geometry_nominal'],
            i,
            [0., FOD-FDD, z],
            api.get_orientation('D'),
            [0., FOD, z],
            api.get_orientation('S'))


if __name__ == '__main__':
    main()